@@ -1,13 +1,19 @@
-import pandas as pd
+from typing import List, Union
+
 import numpy as np
+import pandas as pd
+from joblib import Parallel, delayed
+from ncafs import NCAFSR
 from scipy.special import softmax
 from sklearn.feature_selection import VarianceThreshold
+from sklearn.utils import check_array
 
 from . import get_seed
-from .thirdparty import skfeature
-from .utils import call_module_func
 from .thirdparty import rank_aggregation as ra
+from .thirdparty import skfeature
+from .thirdparty.skfeature import ITFS
 from .thirdparty.entropy_estimators import set_random_generator
+from .utils import call_module_func
 
 
 def _select(F, J, how='cumsum', **kwargs):
@@ -43,6 +49,7 @@ def _prefilter(X, var_threshold=1e-3):
     return sel.get_support()
 
 
+@DeprecationWarning
 def featfilt(df_metadata: pd.DataFrame, max_n_features=10, method='icap', var_filter=True, var_threshold=0, **kwargs):
     """
     Supervised feature filtering function. It involves three steps:
@@ -100,3 +107,46 @@ def featfilt(df_metadata: pd.DataFrame, max_n_features=10, method='icap', var_fi
     blacklist = list(set(orig_feat).difference(set(selected_list)))
 
     return selected_list, df_metadata.drop(columns=blacklist)
+
+
+def filtfeat(X: np.ndarray, Y: np.ndarray, method: str = 'NCA', max_n_features: int = 10,
+             names: List[str] = None, n_jobs: int = 1, **kwargs) -> List[Union[int, str]]:
+    """
+    Filter feature selection. If Y has more than one column, than applies a rank aggregation method to the multi
+    selections.
+
+    :param 2D array-like X: input features array
+    :param 2D array-like Y: output performance array
+    :param str method: whether Neighborhood Component Analysis (NCA, default) or Information Theoretic based (IT)
+    :param max_n_features: max number if features to be selected. Defaults to 10
+    :param names: list with features names (default None). If provided, returns a list of selected features by name;
+        otherwise, returns a list of indices (int)
+    :param int n_jobs: Number of jobs to run in parallel. `-1` means using all processors. Defaults to 1
+    :param kwargs: optional paramters passed to the feature selection method
+    :return: array-like of selected feature
+    """
+    check_array(X, ensure_2d=True)
+    check_array(Y, ensure_2d=True)
+
+    n_instances, n_features = X.shape
+    n_output = Y.shape[1]
+    assert n_instances == Y.shape[0], "X and Y must have the same number of instances."
+
+    FS = {'NCA': NCAFSR, 'IT': ITFS}[method]
+
+    def run_fs(X_, y_, params):
+        fs = FS(**params).fit(X_, y_)
+        w_sort_idx = np.argsort(fs.weights_)[::-1]
+        support = fs.support_[w_sort_idx]
+        return list(map(str, w_sort_idx[support]))
+
+    ranks = Parallel(n_jobs=n_jobs)(delayed(run_fs)(X, Y[:, i], kwargs) for i in range(n_output))
+
+    agg = ra.RankAggregator()
+    selected_list = agg.instant_runoff(ranks)[:max_n_features]
+    selected_indices = list(map(int, selected_list))
+
+    if names is None:
+        return selected_indices
+    else:
+        return [names[i] for i in selected_indices]
