@@ -27,9 +27,9 @@ def classifier_hp_space(name, **kwargs):
 def _objective(predictor, params, X, y):
     predictor = predictor(**params)
     if is_classifier(predictor):
-        score = cross_val_score(predictor, X, y, cv=3, scoring='f1_micro', n_jobs=-1).mean()
+        score = cross_val_score(predictor, X, y, cv=3, scoring='f1_micro', n_jobs=None).mean()
     elif is_regressor(predictor):
-        score = cross_val_score(predictor, X, y, cv=3, scoring='neg_median_absolute_error', n_jobs=-1).mean()
+        score = cross_val_score(predictor, X, y, cv=3, scoring='neg_median_absolute_error', n_jobs=None).mean()
     else:
         raise TypeError("Predictor must be either a classifier or a regressor.")
     return {'loss': -score, 'status': STATUS_OK}
