@@ -299,7 +299,7 @@ class AppClassification(BaseApp):
         @pn.depends(x=self.w_var_x.param.value, y=self.w_var_y.param.value, c=self.w_var_c.param.value,
                     cm=self.w_var_cm.param.value, s=self.w_var_s.param.value)
         def plot_scatter(x, y, c, cm, s, **kwargs):
-            cm = {'Discrete': 'tab20c', 'Continuous': 'coolwarm'}[cm]
+            cm = {'Discrete': 'Set1', 'Continuous': 'coolwarm'}[cm]
             return hv.Scatter(df_all[list({x, y, c})], kdims=[x], vdims=[y, c]).opts(responsive=True,
                                                                                      aspect=1.8,
                                                                                      color=c,
